{% extends "statusboard/base.html" %}

{% load statusboard_extras %}

{% block content %}
<div class="container">
    <div class="page-header">
        <h1>Report a new incident</h1>
    </div>
    {% include "statusboard/incident/form.html" with form=form %}
</div>

{% endblock %}
