{% extends "statusboard/base.html" %}

{% load statusboard_extras %}

{% block content %}
<div class="container">
    <div class="page-header">
        <h1>Create a new maintenance</h1>
    </div>
    {% include "statusboard/maintenance/form.html" %}
</div>
{% endblock %}

