<form class="form-horizontal" role="form" method="post" action="">
    {% csrf_token %}
    <div class="form-group">
        {{ form.name.errors }}
        <label class="control-label col-sm-2" for="{{ form.name.id_for_label }}">Name</label>
        <div class="col-sm-10">
            {{ form.name }}
        </div>
    </div>
    <div class="form-group">
        {{ form.description.errors }}
        <label class="control-label col-sm-2" for="{{ form.description.id_for_label }}">Description</label>
        <div class="col-sm-10">
            {{ form.description }}
        </div>
    </div>
    <div class="form-group">
        {{ form.groups.errors }}
        <label class="control-label col-sm-2" for="{{ form.group.id_for_label }}">Scheduled</label>
        <div class="col-sm-10">
            {{ form.scheduled }}
        </div>
    </div>
    <div class="form-group">
        <div class="col-sm-10 col-sm-offset-2">
            <input type="submit" class="btn btn-primary" value="Submit">
        </div>
    </div>
</form>
