{% extends "statusboard/base.html" %}

{% load statusboard_extras %}

{% block content %}
<div class="container">
    <div class="page-header">
        <h1>Edit maintenance</h1>
    </div>
    {% include "statusboard/service/form.html" %}
</div>
{% endblock %}

